@@ -5,7 +5,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  *   copyright (C) 2003      Brian Thomas <thomas@mail630.gsfc.nasa.gov>   *
- *   copyright (C) 2004-2014                                               *
+ *   copyright (C) 2004-2020                                               *
  *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
  ***************************************************************************/
 
@@ -181,7 +181,7 @@ QString CPPCodeGenerator::fixTypeName(const QString &name)
  * @param doc    the document
  * @param root   the root element
  */
-void CPPCodeGenerator::saveToXMI(QDomDocument & doc, QDomElement & root)
+void CPPCodeGenerator::saveToXMI1(QDomDocument & doc, QDomElement & root)
 {
     QDomElement docElement = doc.createElement(QLatin1String("codegenerator"));
     docElement.setAttribute(QLatin1String("language"), QLatin1String("C++"));
@@ -190,12 +190,12 @@ void CPPCodeGenerator::saveToXMI(QDomDocument & doc, QDomElement & root)
     CodeDocumentList::ConstIterator it  = docList->begin();
     CodeDocumentList::ConstIterator end  = docList->end();
     for (; it != end; ++it)
-        (*it)->saveToXMI(doc, docElement);
+        (*it)->saveToXMI1(doc, docElement);
 
     CodeDocumentList::Iterator it2  = m_headercodedocumentVector.begin();
     CodeDocumentList::Iterator end2  = m_headercodedocumentVector.end();
     for (; it2 != end2; ++it2)
-        (*it2)->saveToXMI(doc, docElement);
+        (*it2)->saveToXMI1(doc, docElement);
 
     root.appendChild(docElement);
 }
@@ -348,7 +348,7 @@ void CPPCodeGenerator::checkAddUMLObject(UMLObject * obj)
     if (isReservedKeyword(obj->name()))
         return;
 
-    UMLClassifier * c = dynamic_cast<UMLClassifier*>(obj);
+    UMLClassifier * c = obj->asUMLClassifier();
     if(c) {
         CodeDocument * cDoc = newClassifierCodeDocument(c);
         CPPHeaderCodeDocument * hcodeDoc = newHeaderClassifierCodeDocument(c);
@@ -370,7 +370,7 @@ void CPPCodeGenerator::checkRemoveUMLObject(UMLObject * obj)
     if (!obj)
         return;
 
-    UMLClassifier * c = dynamic_cast<UMLClassifier*>(obj);
+    UMLClassifier * c = obj->asUMLClassifier();
     if(c) {
         // source
         ClassifierCodeDocument * cDoc = (ClassifierCodeDocument*) findCodeDocumentByClassifier(c);
