@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2014                                               *
+ *   copyright (C) 2002-2020                                               *
  *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
  ***************************************************************************/
 
@@ -55,8 +55,6 @@ AssociationLine::AssociationLine(AssociationWidget *association)
     setFlag(QGraphicsLineItem::ItemIsSelectable);
     setAcceptHoverEvents(true);
     setZValue(3);
-    //setLayout(Uml::LayoutType::Spline);
-    //createSplinePoints();
 }
 
 /**
@@ -117,6 +115,11 @@ QPointF AssociationLine::endPoint() const
     return m_points.at(m_points.size()-1);
 }
 
+void AssociationLine::addPoint(const QPointF &point)
+{
+    m_points.append(point);
+}
+
 /**
  * Inserts the passed in \a point at the \a index passed in and
  * recalculates the bounding rect.
@@ -374,7 +377,7 @@ bool AssociationLine::loadFromXMI1(QDomElement &qElement)
 
 /**
  * Saves association line information into XMI element named "linepath".
- * @note Stored as linepath for backwared compatibility
+ * @note Stored as linepath for backward compatibility
  */
 void AssociationLine::saveToXMI1(QDomDocument &qDoc, QDomElement &qElement)
 {
@@ -508,6 +511,8 @@ void AssociationLine::calculateInitialEndPoints()
     } else if (!m_associationWidget->isSelf() && count() < 2) {
         setEndPoints(QPointF(), QPointF());
     }
+    if (m_layout == Uml::LayoutType::Spline)
+        createSplinePoints();
 }
 
 /**
@@ -1109,16 +1114,17 @@ void AssociationLine::paint(QPainter* painter, const QStyleOptionGraphicsItem* o
         
         // debug info
         if (Tracer::instance()->isEnabled(QString::fromLatin1(metaObject()->className()))) {
-            painter->setPen(Qt::green);
+            QPen p(Qt::green);
+            p.setWidthF(1.0);
+            painter->setPen(p);
             painter->setBrush(Qt::NoBrush);
             painter->drawPath(shape());
-            painter->setPen(Qt::red);
+            painter->setPen(Qt::blue);
             painter->drawRect(boundingRect());
             // origin
             painter->drawLine(-10, 0, 10, 0);
             painter->drawLine(0, -10, 0, 10);
         }
-
     }
 
     // now restore the points array
